@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.006';    # VERSION
+our $VERSION = '0.007';    # VERSION
 
 # ABSTRACT: XGBoost main class for training, prediction and evaluation
 
@@ -36,7 +36,7 @@ sub predict {
     my $data        = $args{'data'};
     my $result      = XGBoosterPredict( $self->_handle, $data->handle );
     my $result_size = scalar @$result;
-    my $matrix_rows = $data->rows;
+    my $matrix_rows = $data->num_row;
     if ( $result_size != $matrix_rows && $result_size % $matrix_rows == 0 ) {
         my $col_size = $result_size / $matrix_rows;
         return [ map { [ @$result[ $_ * $col_size .. $_ * $col_size + $col_size - 1 ] ] } 0 .. $matrix_rows - 1 ];
@@ -100,7 +100,7 @@ AI::XGBoost::Booster - XGBoost main class for training, prediction and evaluatio
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
